#  tests for cookies-2.2.1-py38_1 (this is a generated file);
print('===== testing package: cookies-2.2.1-py38_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
# new cookies.py
from cookies import Cookies, Cookie

cookies = Cookies(rocky='road')
# Can also write explicitly: cookies['rocky'] = Cookie['road']
cookies['rocky'].path = "/cookie"
assert cookies.render_request() == 'rocky=road'
#  --- run_test.py (end) ---

print('===== cookies-2.2.1-py38_1 OK =====');
print("import: 'cookies'")
import cookies

